@@ -102,7 +102,7 @@ class Panda(QtGui.QMainWindow): #main class
 		self.ui.btnLove.setStyleSheet("background-image: url(:/img/img/thumbup_small.png);\nborder: rgb(0, 0, 0);\nbackground-color: rgb(100, 100, 100);")
 		self.ui.btnHate.setStyleSheet("background-color: rgb(100, 100, 100);\nborder: rgb(255, 255, 255);\nbackground-image: url(:/img/img/thumbdwn_small.png);")
 		self.player = RadioPlayer()
-		self.player.start()
+		self.stimer.singleShot(50, self.player.start)
 		self.os = self.player.get_product()
 		if self.os != "RX-51": #check for N900 
 			self.ui.albumArt.setStyleSheet("background-color: rgb(255, 255, 255);")
@@ -203,11 +203,14 @@ class Panda(QtGui.QMainWindow): #main class
 		QtGui.QApplication.processEvents()
 		authenticated = self.player.auth( self.c.user, self.c.password )
 		if not authenticated:
+			self.c.user = ""
+			self.c.password = ""
 			self.auth( count )
-		self.ui.albumArt.setHtml( "<table width='100%' height='100%'><tr height='100%'><td height='100%' valign='middle'><font style='color: #fff'>Authentication successful.  Select a station from list to the right.</font></td><tr></table>" )
-		QtGui.QApplication.processEvents()
-		self.c.write()
-		self.getStations()
+		else:
+			self.ui.albumArt.setHtml( "<table width='100%' height='100%'><tr height='100%'><td height='100%' valign='middle'><font style='color: #fff'>Authentication successful.  Select a station from list to the right.</font></td><tr></table>" )
+			QtGui.QApplication.processEvents()
+			self.c.write()
+			self.getStations()
 
 	def playStation( self ): #Play currently selected station
 		stationId = self.stations[self.ui.listStations.currentIndex()]['stationId']	
